==> gnome-apt_0.3.15-3.tar.gz: gnome-apt-0.3.15/src/pkglist.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *   Gnome Apt frontend
 *
 *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GNOME_APT_PKGLIST_H
#define GNOME_APT_PKGLIST_H

#include "gnome-apt.h"
#include "pkgtree.h"
#include "infopanes.h"
#include "filterbar.h"
#include "details.h"

class GAptPkgList {
public:
  GAptPkgList(GAptPkgTree* tree, GnomeAppBar* bar);
  ~GAptPkgList();

  GtkWidget* widget() { return paned_; }

  GAptPkgTree* tree() { return tree_; }

  Filter* filter() { return filter_; }

  void set_selection(pkgCache::Package* pkg);

  pkgCache::Package* get_selection() { return selection_; }

  // Preferences
  void set_info_hidden(bool state);
  bool get_info_hidden() { return info_->get_hidden(); }

  // Menu items
  void install();
  void remove();
  void keep();
  void details();
  void search();

private:
  GtkWidget*   paned_;
  
  // bottom pane (tree)
  GAptPkgTree* tree_;
  GtkWidget* table_;
  GtkWidget* tree_frame_;

  // top pane (info/description)
  GAptInfoPanes* info_;

  // Filter
  Filter*        filter_;
  GAptFilterBar* filterbar_;

  pkgCache::Package* selection_;

  // Details window
  Details details_;
};


#endif

==> gnome-apt_0.4.7-1.2.tar.gz: gnome-apt-0.4.7/src/pkglist.h <==
/* -*- Mode: C++; tab-width: 4 -*-
 * vim: sw=4 ts=4:
 *
 * Gnome Apt package cache handling class
 *
 * 	(C) 1998 Havoc Pennington <hp@pobox.com>
 * 	    2003 Filip Van Raemdonck <mechanix@debian.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 *
 * 	$Id$
 *
 **/

#ifndef GNOME_APT_PKGLIST_H
#define GNOME_APT_PKGLIST_H

#include <libgnomeui/gnome-appbar.h>

#include "cachecontrol.h"
#include "details.h"

class GAptFilterBar;
class GAptInfoPanes;
class DrawTree;

class GAptPkgList {
public:
	GAptPkgList (DrawTree*, GnomeAppBar*);
	~GAptPkgList (void);

	GtkWidget* widget (void) { return pl_wdg; }
	DrawTree* getView (void) { return pl_treeview; }
	GAptCacheControl* getCacheControl (void) { return pl_cachectrl; }

  void set_selection(pkgCache::Package* pkg);

  // Menu items
  void install();
  void remove();
	void keep (void);
	void details (bool);

private:
	GtkWidget* pl_wdg;
	DrawTree* pl_treeview;
	GAptCacheControl* pl_cachectrl;

	/* Filter */
  GAptFilterBar* filterbar_;

  pkgCache::Package* selection_;

  // Details window
  Details details_;
};

#endif
